@@ -47,8 +47,8 @@ def compact(number):
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid VAT number. This checks
-    the length, formatting and check digit."""
+    """Check if the number provided is a valid VAT number. This checks the
+    length, formatting and check digit."""
     number = compact(number)
     if not number.isdigit() or number[0] == '0':
         raise InvalidFormat()
@@ -59,8 +59,8 @@ def validate(number):
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid VAT number. This checks
-    the length, formatting and check digit."""
+    """Check if the number provided is a valid VAT number. This checks the
+    length, formatting and check digit."""
     try:
         return bool(validate(number))
     except ValidationError:
