@@ -89,22 +89,22 @@ def get_birth_date(number):
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid CPR number. This
-    checks the length, formatting, embedded date and check digit."""
+    """Check if the number provided is a valid CPR number. This checks the
+    length, formatting, embedded date and check digit."""
     number = compact(number)
     if not number.isdigit():
         raise InvalidFormat()
     if len(number) != 10:
         raise InvalidLength()
     # check if birth date is valid
-    birth_date = get_birth_date(number)
+    get_birth_date(number)
     # TODO: check that the birth date is not in the future
     return number
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid CPR number. This
-    checks the length, formatting, embedded date and check digit."""
+    """Check if the number provided is a valid CPR number. This checks the
+    length, formatting, embedded date and check digit."""
     try:
         return bool(validate(number))
     except ValidationError:
@@ -112,6 +112,6 @@ def is_valid(number):
 
 
 def format(number):
-    """Reformat the passed number to the standard format."""
+    """Reformat the number to the standard presentation format."""
     number = compact(number)
     return '-'.join((number[:6], number[6:]))
