@@ -1,7 +1,7 @@
 # rnc.py - functions for handling Dominican Republic tax registration
 # coding: utf-8
 #
-# Copyright (C) 2015-2017 Arthur de Jong
+# Copyright (C) 2015-2018 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -115,12 +115,12 @@ def _convert_result(result):  # pragma: no cover
         for key, value in json.loads(result.replace('\t', '\\t')).items())
 
 
-def check_dgii(number):  # pragma: no cover
+def check_dgii(number, timeout=30):  # pragma: no cover
     """Lookup the number using the DGII online web service.
 
     This uses the validation service run by the the Dirección General de
     Impuestos Internos, the Dominican Republic tax department to lookup
-    registration information for the number.
+    registration information for the number. The timeout is in seconds.
 
     Returns a dict with the following structure::
 
@@ -133,23 +133,25 @@ def check_dgii(number):  # pragma: no cover
             'payment_regime': '2',  # 1: N/D, 2: NORMAL, 3: PST
         }
 
-    Will return none if the number is invalid or unknown."""
+    Will return None if the number is invalid or unknown."""
     # this function isn't automatically tested because it would require
     # network access for the tests and unnecessarily load the online service
     number = compact(number)
-    client = get_soap_client(dgii_wsdl)
-    result = '%s' % client.GetContribuyentes(
+    client = get_soap_client(dgii_wsdl, timeout)
+    result = client.GetContribuyentes(
         value=number,
         patronBusqueda=0,   # search type: 0=by number, 1=by name
         inicioFilas=1,      # start result (1-based)
         filaFilas=1,        # end result
         IMEI='')
+    if result and 'GetContribuyentesResult' in result:
+        result = result['GetContribuyentesResult']  # PySimpleSOAP only
     if result == '0':
         return
     return _convert_result(result)
 
 
-def search_dgii(keyword, end_at=10, start_at=1):  # pragma: no cover
+def search_dgii(keyword, end_at=10, start_at=1, timeout=30):  # pragma: no cover
     """Search the DGII online web service using the keyword.
 
     This uses the validation service run by the the Dirección General de
@@ -157,7 +159,7 @@ def search_dgii(keyword, end_at=10, start_at=1):  # pragma: no cover
     registration information using the keyword.
 
     The number of entries returned can be tuned with the `end_at` and
-    `start_at` arguments.
+    `start_at` arguments. The timeout is in seconds.
 
     Returns a list of dicts with the following structure::
 
@@ -177,13 +179,15 @@ def search_dgii(keyword, end_at=10, start_at=1):  # pragma: no cover
     Will return an empty list if the number is invalid or unknown."""
     # this function isn't automatically tested because it would require
     # network access for the tests and unnecessarily load the online service
-    client = get_soap_client(dgii_wsdl)
-    results = '%s' % client.GetContribuyentes(
+    client = get_soap_client(dgii_wsdl, timeout)
+    results = client.GetContribuyentes(
         value=keyword,
         patronBusqueda=1,       # search type: 0=by number, 1=by name
         inicioFilas=start_at,   # start result (1-based)
         filaFilas=end_at,       # end result
         IMEI='')
+    if results and 'GetContribuyentesResult' in results:
+        results = results['GetContribuyentesResult']  # PySimpleSOAP only
     if results == '0':
         return []
     return [_convert_result(result) for result in results.split('@@@')]
