@@ -104,6 +104,8 @@ def validate(number, check_country=True):
     mod_97_10.validate(number[4:] + number[:4])
     # look up the number
     info = _ibandb.info(number)
+    if not info[0][1]:
+        raise InvalidComponent()
     # check if the bban part of number has the correct structure
     bban = number[4:]
     if not _struct_to_re(info[0][1].get('bban', '')).match(bban):
