@@ -1,6 +1,6 @@
 # nip.py - functions for handling Polish VAT numbers
 #
-# Copyright (C) 2012, 2013 Arthur de Jong
+# Copyright (C) 2012-2015 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -48,12 +48,12 @@ def compact(number):
 def checksum(number):
     """Calculate the checksum."""
     weights = (6, 5, 7, 2, 3, 4, 5, 6, 7, -1)
-    return sum(weights[i] * int(n) for i, n in enumerate(number)) % 11
+    return sum(w * int(n) for w, n in zip(weights, number)) % 11
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid VAT number. This
-    checks the length, formatting and check digit."""
+    """Check if the number is a valid VAT number. This checks the length,
+    formatting and check digit."""
     number = compact(number)
     if not number.isdigit():
         raise InvalidFormat()
@@ -65,8 +65,7 @@ def validate(number):
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid VAT number. This
-    checks the length, formatting and check digit."""
+    """Check if the number is a valid VAT number."""
     try:
         return bool(validate(number))
     except ValidationError:
@@ -74,6 +73,6 @@ def is_valid(number):
 
 
 def format(number):
-    """Reformat the passed number to the standard format."""
+    """Reformat the number to the standard presentation format."""
     number = compact(number)
     return '-'.join((number[0:3], number[3:6], number[6:8], number[8:]))
